@@ -1,5 +1,7 @@
 __all__ = [
+    "bruker_meta_objects",
     "bruker_xml_objects",
+    "configuration_values",
     "data_sync",
     "io_tools"
     "mark_points",
