@@ -10,7 +10,7 @@ from prettytable import PrettyTable
 from PIL import Image
 from PPVD.parsing import convert_permitted_types_to_required, find_num_unique_files_given_static_substring, \
     find_num_unique_files_containing_tag
-from PPVD.validation import validate_path, validate_extension, validate_strong_type, validate_exists
+from PPVD.validation import validate_extension
 from tqdm.auto import tqdm
 from tqdm import tqdm as tq
 from tifffile import TiffWriter
@@ -49,9 +49,7 @@ def _pretty_print_image_description(channels: int, planes: int, frames: int, hei
 
 
 @convert_permitted_types_to_required(permitted=(str, pathlib.Path), required=str, pos=0)
-@validate_path(pos=0)
 @validate_extension(required_extension=".csv", pos=0)
-@validate_exists(pos=0)
 def _import_csv(path: str) -> pd.DataFrame:
     """
     Implementation function for loading csv files. Abstracted from the upper-level functions for cleaner logic.
@@ -127,7 +125,8 @@ def determine_imaging_content(folder: Union[str, pathlib.Path]) -> Tuple[int, in
     channels = find_channels()
 
     # noinspection PyTypeChecker
-    return channels, find_planes(), find_frames(), *find_dimensions()
+    return channels, find_planes(), find_frames(), find_dimensions()[0], find_dimensions()[1]
+    # apparently * on a return is illegal for python 3.7
 
 
 @convert_permitted_types_to_required(permitted=(str, pathlib.Path), required=pathlib.Path, pos=0)
@@ -430,9 +429,7 @@ def load_xml(folder: str) -> None:
 
 
 @convert_permitted_types_to_required(permitted=(str, pathlib.Path), required=str, pos=0)
-@validate_path(pos=0)
 @validate_extension(required_extension=".csv", pos=0)
-@validate_strong_type(required=int, pos=2)
 def write_csv(path: str, data: np.ndarray, sampling_rate: int = 10000) -> None:
     """
     Write a CSV file for custom electrophysiology stimuli in PrairieView.
